@@ -34,12 +34,6 @@
 #include "config-data.h"
 #include "common/authentication.h"
 
-#define d(x)
-
-#define ALARM_NOTIFY_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), TYPE_ALARM_NOTIFY, AlarmNotifyPrivate))
-
 struct _AlarmNotifyPrivate {
 	/* Mapping from EUri's to LoadedClient structures */
 	/* FIXME do we need per source type uri hashes? or perhaps we
@@ -125,15 +119,14 @@ alarm_notify_list_changed_cb (ESourceList *source_list,
 		for (q = sources; q != NULL; q = q->next) {
 			ESource *source = E_SOURCE (q->data);
 			gchar *uri;
-			const gchar *completion = e_source_get_property (source, "alarm");
+			const gchar *alarm = e_source_get_property (source, "alarm");
 
-			if (completion  && (!g_ascii_strcasecmp (completion, "false") ||
-						!g_ascii_strcasecmp (completion, "never")))
+			if (alarm && (!g_ascii_strcasecmp (alarm, "false") || !g_ascii_strcasecmp (alarm, "never")))
 				continue;
 
 			uri = e_source_get_uri (source);
 			if (!g_hash_table_lookup (an->priv->uri_client_hash[source_type], uri)) {
-				d (printf("%s:%d (list_changed_cb) - Adding Calendar %s\n", __FILE__, __LINE__, uri));
+				debug (("Adding Calendar %s", uri));
 				alarm_notify_add_calendar (an, source_type, source, FALSE);
 			}
 			g_free (uri);
@@ -147,7 +140,7 @@ alarm_notify_list_changed_cb (ESourceList *source_list,
 	g_hash_table_foreach (an->priv->uri_client_hash[source_type], (GHFunc) process_removal_in_hash, &prd);
 
 	for (l = prd.removals; l; l = l->next) {
-		d (printf("%s:%d (list_changed_cb) - Removing Calendar %s\n", __FILE__, __LINE__, (gchar *)l->data));
+		debug (("Removing Calendar %s", (gchar *)l->data));
 		alarm_notify_remove_calendar (an, source_type, l->data);
 	}
 	g_list_free (prd.removals);
@@ -164,7 +157,7 @@ alarm_notify_load_calendars (AlarmNotify *an,
 	GSList *groups, *sources, *p, *q;
 
 	if (!e_cal_get_sources (&source_list, source_type, NULL)) {
-		d (printf("%s:%d (load_calendars) - Cannont get sources\n ", __FILE__, __LINE__));
+		debug (("Cannont get sources"));
 		an->priv->source_lists[source_type] = NULL;
 
 		return;
@@ -178,20 +171,20 @@ alarm_notify_load_calendars (AlarmNotify *an,
 		for (q = sources; q != NULL; q = q->next) {
 			ESource *source = E_SOURCE (q->data);
 			gchar *uri;
-			const gchar *completion = e_source_get_property (source, "alarm");
+			const gchar *alarm = e_source_get_property (source, "alarm");
 
-			if (completion  && (!g_ascii_strcasecmp (completion, "false") ||
-						!g_ascii_strcasecmp (completion, "never")))
+			if (alarm && (!g_ascii_strcasecmp (alarm, "false") || !g_ascii_strcasecmp (alarm, "never")))
 				continue;
 
 			uri = e_source_get_uri (source);
-			d (printf("%s:%d (load_calendars) - Loading Calendar %s \n", __FILE__, __LINE__, uri));
+			debug (("Loading Calendar %s", uri));
 			alarm_notify_add_calendar (an, source_type, source, FALSE);
 			g_free (uri);
 
 		}
 	}
 
+	e_source_list_sync (source_list, NULL);
 	g_signal_connect_object (
 		source_list, "changed",
 		G_CALLBACK (alarm_notify_list_changed_cb), an, 0);
@@ -211,7 +204,7 @@ alarm_notify_finalize (GObject *object)
 	AlarmNotifyPrivate *priv;
 	gint ii;
 
-	priv = ALARM_NOTIFY_GET_PRIVATE (object);
+	priv = ALARM_NOTIFY (object)->priv;
 
 	for (ii = 0; ii < E_CAL_SOURCE_TYPE_LAST; ii++) {
 		g_hash_table_foreach (
@@ -245,7 +238,8 @@ alarm_notify_init (AlarmNotify *an)
 {
 	gint ii;
 
-	an->priv = ALARM_NOTIFY_GET_PRIVATE (an);
+	an->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		an, TYPE_ALARM_NOTIFY, AlarmNotifyPrivate);
 	an->priv->mutex = g_mutex_new ();
 	an->priv->selected_calendars = config_data_get_calendars (
 		"/apps/evolution/calendar/sources");
@@ -308,16 +302,16 @@ alarm_notify_new (void)
 }
 
 static void
-cal_opened_cb (ECal *client, ECalendarStatus status, gpointer user_data)
+cal_opened_cb (ECal *client, const GError *error, gpointer user_data)
 {
 	AlarmNotifyPrivate *priv;
 	AlarmNotify *an = ALARM_NOTIFY (user_data);
 
 	priv = an->priv;
 
-	d (printf("%s:%d (cal_opened_cb) %s - Calendar Status %d\n", __FILE__, __LINE__, e_cal_get_uri (client), status));
+	debug (("%s - Calendar Status %d%s%s%s", e_cal_get_uri (client), error ? error->code : 0, error ? " (" : "", error ? error->message : "", error ? ")" : ""));
 
-	if (status == E_CALENDAR_STATUS_OK)
+	if (!error)
 		alarm_queue_add_client (client);
 	else {
 		g_hash_table_remove (priv->uri_client_hash[e_cal_get_source_type (client)],
@@ -374,26 +368,28 @@ alarm_notify_add_calendar (AlarmNotify *an, ECalSourceType source_type,  ESource
 		const gchar *name = e_source_get_property (source, "auth-domain");
 
 		if (!name)
-			name = e_source_peek_name (source);
+			name = "Calendar";
 
 		if (!e_passwords_get_password (name, pass_key)) {
 			g_mutex_unlock (an->priv->mutex);
 			g_free (str_uri);
 			g_free (pass_key);
+
 			return;
 		}
 	}
 
-	client = auth_new_cal_from_source (source, source_type);
+	client = e_auth_new_cal_from_source (source, source_type);
 
 	if (client) {
-		d (printf("%s:%d (alarm_notify_add_calendar) %s - Calendar Open Async... %p\n", __FILE__, __LINE__, str_uri, client));
+		debug (("%s - Calendar Open Async... %p", str_uri, client));
 		g_hash_table_insert (priv->uri_client_hash[source_type], g_strdup (str_uri), client);
-		g_signal_connect (G_OBJECT (client), "cal_opened", G_CALLBACK (cal_opened_cb), an);
+		g_signal_connect (G_OBJECT (client), "cal_opened_ex", G_CALLBACK (cal_opened_cb), an);
 		/* to resolve floating DATE-TIME properly */
 		e_cal_set_default_timezone (client, config_data_get_timezone (), NULL);
 		e_cal_open_async (client, FALSE);
 	}
+
 	g_free (str_uri);
 	g_free (pass_key);
 	g_mutex_unlock (an->priv->mutex);
@@ -409,7 +405,7 @@ alarm_notify_remove_calendar (AlarmNotify *an, ECalSourceType source_type, const
 
 	client = g_hash_table_lookup (priv->uri_client_hash[source_type], str_uri);
 	if (client) {
-		d (printf("%s:%d (alarm_notify_remove_calendar) - Removing Client %p\n", __FILE__, __LINE__, client));
+		debug (("Removing Client %p", client));
 		alarm_queue_remove_client (client, FALSE);
 		g_hash_table_remove (priv->uri_client_hash[source_type], str_uri);
 	}
