@@ -60,13 +60,6 @@
 #include "e-util/e-alert-dialog.h"
 #include "e-util/e-ui-manager.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
-#define COMP_EDITOR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), TYPE_COMP_EDITOR, CompEditorPrivate))
-
 #define d(x)
 
 /* Private part of the CompEditor structure */
@@ -210,7 +203,8 @@ static void obj_removed_cb (ECal *client, GList *uids, CompEditor *editor);
 
 G_DEFINE_TYPE_WITH_CODE (
 	CompEditor, comp_editor, GTK_TYPE_WINDOW,
-	G_IMPLEMENT_INTERFACE (E_TYPE_ALERT_SINK, NULL))
+	G_IMPLEMENT_INTERFACE (E_TYPE_ALERT_SINK, NULL);
+	G_IMPLEMENT_INTERFACE (E_TYPE_EXTENSIBLE, NULL))
 
 enum {
 	OBJECT_CREATED,
@@ -231,7 +225,7 @@ static void
 attachment_store_changed_cb (CompEditor *editor)
 {
 	/* Mark the editor as changed so it prompts about unsaved
-           changes on close */
+	   changes on close */
 	comp_editor_set_changed (editor, TRUE);
 }
 
@@ -494,12 +488,11 @@ save_comp (CompEditor *editor)
 		}
 		result = e_cal_modify_object (priv->client, icalcomp, priv->mod, &error);
 
-		if (result && priv->mod == CALOBJ_MOD_THIS) {
-			/* FIXME do we really need to do this ? */
-			if ((flags & COMP_EDITOR_DELEGATE) ||
+		if (priv->mod == CALOBJ_MOD_THIS) {
+			if (result && ((flags & COMP_EDITOR_DELEGATE) ||
 				!e_cal_component_has_organizer (clone) ||
 				itip_organizer_is_user (clone, priv->client) ||
-				itip_sentby_is_user (clone, priv->client))
+				itip_sentby_is_user (clone, priv->client)))
 				e_cal_component_commit_sequence (clone);
 			else
 				e_cal_component_abort_sequence (clone);
@@ -1420,12 +1413,33 @@ comp_editor_get_property (GObject *object,
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 }
 
+static void
+unref_page_cb (gpointer editor_page, gpointer comp_editor)
+{
+	if (IS_COMP_EDITOR_PAGE (editor_page)) {
+		GtkWidget *page_widget;
+		CompEditorPage *page = COMP_EDITOR_PAGE (editor_page);
+		CompEditor *editor = COMP_EDITOR (comp_editor);
+
+		g_return_if_fail (page != NULL);
+		g_return_if_fail (editor != NULL);
+
+		page_widget = comp_editor_page_get_widget (page);
+		g_signal_handlers_disconnect_matched (
+			page_widget, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, page);
+	}
+
+	g_signal_handlers_disconnect_matched (
+		editor_page, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, comp_editor);
+	g_object_unref (editor_page);
+}
+
 static void
 comp_editor_dispose (GObject *object)
 {
 	CompEditorPrivate *priv;
 
-	priv = COMP_EDITOR_GET_PRIVATE (object);
+	priv = COMP_EDITOR (object)->priv;
 
 	if (priv->shell != NULL) {
 		g_object_remove_weak_pointer (
@@ -1466,7 +1480,7 @@ comp_editor_dispose (GObject *object)
 	/* We want to destroy the pages after the widgets get destroyed,
 	   since they have lots of signal handlers connected to the widgets
 	   with the pages as the data. */
-	g_list_foreach (priv->pages, (GFunc) g_object_unref, NULL);
+	g_list_foreach (priv->pages, (GFunc) unref_page_cb, object);
 	g_list_free (priv->pages);
 	priv->pages = NULL;
 
@@ -1489,7 +1503,7 @@ comp_editor_finalize (GObject *object)
 {
 	CompEditorPrivate *priv;
 
-	priv = COMP_EDITOR_GET_PRIVATE (object);
+	priv = COMP_EDITOR (object)->priv;
 
 	g_free (priv->summary);
 
@@ -1497,6 +1511,15 @@ comp_editor_finalize (GObject *object)
 	G_OBJECT_CLASS (comp_editor_parent_class)->finalize (object);
 }
 
+static void
+comp_editor_constructed (GObject *object)
+{
+	e_extensible_load_extensions (E_EXTENSIBLE (object));
+
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (comp_editor_parent_class)->constructed (object);
+}
+
 static void
 comp_editor_bind_gconf (CompEditor *editor)
 {
@@ -1581,7 +1604,7 @@ comp_editor_drag_motion (GtkWidget *widget,
 	CompEditorPrivate *priv;
 	EAttachmentView *view;
 
-	priv = COMP_EDITOR_GET_PRIVATE (widget);
+	priv = COMP_EDITOR (widget)->priv;
 	view = E_ATTACHMENT_VIEW (priv->attachment_view);
 
 	return e_attachment_view_drag_motion (view, context, x, y, time);
@@ -1599,7 +1622,7 @@ comp_editor_drag_data_received (GtkWidget *widget,
 	CompEditorPrivate *priv;
 	EAttachmentView *view;
 
-	priv = COMP_EDITOR_GET_PRIVATE (widget);
+	priv = COMP_EDITOR (widget)->priv;
 	view = E_ATTACHMENT_VIEW (priv->attachment_view);
 
 	/* Forward the data to the attachment view.  Note that calling
@@ -1624,6 +1647,7 @@ comp_editor_class_init (CompEditorClass *class)
 	object_class->get_property = comp_editor_get_property;
 	object_class->dispose = comp_editor_dispose;
 	object_class->finalize = comp_editor_finalize;
+	object_class->constructed = comp_editor_constructed;
 
 	widget_class = GTK_WIDGET_CLASS (class);
 	widget_class->delete_event = comp_editor_delete_event;
@@ -1807,7 +1831,8 @@ comp_editor_init (CompEditor *editor)
 	express_mode = e_shell_get_express_mode (shell);
 	meego_mode = e_shell_get_meego_mode (shell);
 
-	editor->priv = priv = COMP_EDITOR_GET_PRIVATE (editor);
+	editor->priv = priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		editor, TYPE_COMP_EDITOR, CompEditorPrivate);
 
 	g_object_weak_ref (
 		G_OBJECT (editor), (GWeakNotify)
@@ -2580,8 +2605,7 @@ page_unmapped_cb (GtkWidget *page_widget,
 		return;
 
 	if (page->accel_group) {
-		gtk_window_remove_accel_group (GTK_WINDOW (toplevel),
-					       page->accel_group);
+		gtk_window_remove_accel_group (GTK_WINDOW (toplevel), page->accel_group);
 	}
 }
 
@@ -2615,8 +2639,12 @@ comp_editor_append_widget (CompEditor *editor,
 
 	priv->pages = g_list_append (priv->pages, page);
 
-	if (add)
+	if (add) {
 		gtk_notebook_append_page (priv->notebook, page, label_widget);
+		gtk_container_child_set (
+			GTK_CONTAINER (priv->notebook), page,
+			"tab-fill", FALSE, "tab-expand", FALSE, NULL);
+	}
 
 	/* Listen for when the page is mapped/unmapped so we can
 	   install/uninstall the appropriate GtkAccelGroup.
@@ -2677,8 +2705,13 @@ comp_editor_append_page (CompEditor *editor,
 
 	priv->pages = g_list_append (priv->pages, page);
 
-	if (add)
-		gtk_notebook_append_page (priv->notebook, page_widget, label_widget);
+	if (add) {
+		gtk_notebook_append_page (
+			priv->notebook, page_widget, label_widget);
+		gtk_container_child_set (
+			GTK_CONTAINER (priv->notebook), page_widget,
+			"tab-fill", FALSE, "tab-expand", FALSE, NULL);
+	}
 
 	/* Listen for things happening on the page */
 	g_signal_connect_swapped (
@@ -3161,11 +3194,11 @@ comp_editor_get_comp (CompEditor *editor)
 
 /**
  * comp_editor_get_current_comp
+ * @editor: a #CompEditor
+ * @correct: Set this no non-%NULL if you are interested to know if all
+ * pages reported success when filling component.
  *
- * @param editor
- * @param correct Set this no non-NULL if you are interested to know if
- *                all pages reported success when filling component.
- * @return Newly allocated component, should be unref-ed by g_object_unref.
+ * Returns: Newly allocated component, should be unref-ed by g_object_unref().
  **/
 ECalComponent *
 comp_editor_get_current_comp (CompEditor *editor, gboolean *correct)
@@ -3420,4 +3453,3 @@ obj_removed_cb (ECal *client,
 	if (changed_component_dialog ((GtkWindow *) editor, priv->comp, TRUE, priv->changed))
 		close_dialog (editor);
 }
-
