@@ -118,7 +118,6 @@ static void
 mail_view_class_init (MailViewClass *klass)
 {
 	GObjectClass * object_class = G_OBJECT_CLASS (klass);
-	AnjalMailViewClass *pclass;
 	signals[VIEW_NEW] =
 		g_signal_new ("view-new",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -128,7 +127,7 @@ mail_view_class_init (MailViewClass *klass)
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
 
-	pclass = mail_view_parent_class = g_type_class_peek_parent (klass);
+	mail_view_parent_class = g_type_class_peek_parent (klass);
 	((AnjalMailViewClass *)klass)->set_folder_uri = mv_set_folder_uri;
 	((AnjalMailViewClass *)klass)->set_folder_tree = set_folder_tree;
 	((AnjalMailViewClass *)klass)->set_search = set_search;
@@ -314,7 +313,7 @@ mail_view_add_folder (MailView *mv, gpointer data, gboolean block)
 	mv->priv->children = block ? g_list_append (mv->priv->children,  mfv) :  g_list_prepend (mv->priv->children,  mfv);
 	position = gtk_notebook_append_page ((GtkNotebook *)mv, (GtkWidget *)mfv, mfv->tab_label);
 	gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (mv), (GtkWidget *)mfv, TRUE);
-        gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)mfv, FALSE);
+	gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)mfv, FALSE);
 
 	g_signal_connect (mfv, "view-close", G_CALLBACK(mv_close_mcv), mv);
 	if (!block)
@@ -355,7 +354,7 @@ mail_view_add_composer (MailView *mv, gpointer data, gboolean block)
 	}
 
 	gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (mv), (GtkWidget *)mcv, TRUE);
-        gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)mcv, FALSE);
+	gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)mcv, FALSE);
 	if (!block)
 		 gtk_notebook_set_current_page ((GtkNotebook *)mv, position);
 	if (!block)
@@ -382,7 +381,7 @@ mail_view_add_message (MailView *mv, gpointer data, gboolean block)
 	position = gtk_notebook_get_current_page ((GtkNotebook *)mv);
 	gtk_notebook_insert_page ((GtkNotebook *)mv, (GtkWidget *)mcv, mail_conv_view_get_tab_widget (mcv), position+1);
 	gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (mv), (GtkWidget *)mcv, TRUE);
-        gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)mcv, FALSE);
+	gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)mcv, FALSE);
 	if (!block)
 		gtk_notebook_set_current_page ((GtkNotebook *)mv, position+1);
 	if (!block)
@@ -417,7 +416,7 @@ mail_view_add_settings (MailView *mv, gpointer data, gboolean block)
 	g_signal_connect (msv, "view-close", G_CALLBACK(mv_close_mcv), mv);
 	g_signal_connect (msv, "show-account", G_CALLBACK(mv_show_acc_mcv), mv);
 	gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (mv), (GtkWidget *)msv, TRUE);
-        gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)msv, FALSE);
+	gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)msv, FALSE);
 	if (!block)
 		gtk_notebook_set_current_page ((GtkNotebook *)mv, position);
 	if (!block)
@@ -438,11 +437,14 @@ mail_view_switch_to_settings (MailView* mv, MailViewChild *mpv)
 }
 
 static MailViewChild *
-mail_view_add_account (MailView *mv, gpointer data, gboolean block)
+mail_view_add_account (MailView *mv,
+                       gpointer data,
+                       gboolean block)
 {
-	MailAccountView *msv  = mail_account_view_new (data);
+	MailAccountView *msv;
 	gint position = 0;
 
+	msv = mail_account_view_new (data, mv->session);
 	gtk_widget_show ((GtkWidget *)msv);
 	if (!block)
 		mv->priv->current_view = (MailViewChild *)msv;
@@ -450,7 +452,7 @@ mail_view_add_account (MailView *mv, gpointer data, gboolean block)
 	position = gtk_notebook_append_page ((GtkNotebook *)mv, (GtkWidget *)msv, mail_account_view_get_tab_widget (msv));
 	g_signal_connect_after (msv, "view-close", G_CALLBACK(mv_close_mcv), mv);
 	gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (mv), (GtkWidget *)msv, TRUE);
-        gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)msv, FALSE);
+	gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (mv), (GtkWidget *)msv, FALSE);
 	if (!block)
 		gtk_notebook_set_current_page ((GtkNotebook *)mv, position);
 	if (!block)
