@@ -105,8 +105,8 @@ ecb_dispose (GObject *object)
 		ecb->priv = NULL;
 	}
 
-	if (G_OBJECT_CLASS (ecb_parent_class)->dispose)
-                G_OBJECT_CLASS (ecb_parent_class)->dispose (object);
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (ecb_parent_class)->dispose (object);
 }
 
 static void
@@ -115,14 +115,11 @@ ecb_set_property (GObject *object,
 		  const GValue *value,
 		  GParamSpec *pspec)
 {
-	GnomeCanvasItem *item;
 	ECanvasBackground *ecb;
 
 	GdkColor color = { 0, 0, 0, 0, };
 	GdkColor *pcolor;
-	gboolean color_changed = FALSE;
 
-	item = GNOME_CANVAS_ITEM (object);
 	ecb = E_CANVAS_BACKGROUND (object);
 
 	switch (prop_id) {
@@ -134,7 +131,6 @@ ecb_set_property (GObject *object,
 				   (color.green & 0xff00) << 8 |
 				   (color.blue & 0xff00) |
 				   0xff);
-		color_changed = TRUE;
 		break;
 
 	case PROP_FILL_COLOR_GDK:
@@ -147,12 +143,10 @@ ecb_set_property (GObject *object,
 				   (color.green & 0xff00) << 8 |
 				   (color.blue & 0xff00) |
 				   0xff);
-		color_changed = TRUE;
 		break;
 
-        case PROP_FILL_COLOR_RGBA:
+	case PROP_FILL_COLOR_RGBA:
 		ecb->priv->rgba = g_value_get_uint (value);
-		color_changed = TRUE;
 		break;
 
 	}
@@ -171,7 +165,7 @@ ecb_get_property (GObject *object,
 	ecb = E_CANVAS_BACKGROUND (object);
 
 	switch (prop_id) {
-        case PROP_FILL_COLOR_RGBA:
+	case PROP_FILL_COLOR_RGBA:
 		g_value_set_uint (value, ecb->priv->rgba);
 		break;
 	default:
@@ -188,23 +182,22 @@ ecb_init (ECanvasBackground *ecb)
 
 static void
 ecb_draw (GnomeCanvasItem *item,
-          GdkDrawable *drawable,
+          cairo_t *cr,
           gint x,
           gint y,
           gint width,
           gint height)
 {
 	ECanvasBackground *ecb = E_CANVAS_BACKGROUND (item);
-        cairo_t *cr;
 
-        cr = gdk_cairo_create (drawable);
-        cairo_set_source_rgba (cr,
-                               ((ecb->priv->rgba >> 24) & 0xff) / 255.0,
-                               ((ecb->priv->rgba >> 16) & 0xff) / 255.0,
-                               ((ecb->priv->rgba >>  8) & 0xff) / 255.0,
-                               ( ecb->priv->rgba        & 0xff) / 255.0);
-        cairo_paint (cr);
-        cairo_destroy (cr);
+	cairo_save (cr);
+	cairo_set_source_rgba (cr,
+			       ((ecb->priv->rgba >> 24) & 0xff) / 255.0,
+			       ((ecb->priv->rgba >> 16) & 0xff) / 255.0,
+			       ((ecb->priv->rgba >>  8) & 0xff) / 255.0,
+			       ( ecb->priv->rgba        & 0xff) / 255.0);
+	cairo_paint (cr);
+	cairo_restore (cr);
 }
 
 static GnomeCanvasItem *
@@ -218,13 +211,9 @@ ecb_style_set (ECanvasBackground *ecb,
                GtkStyle *previous_style)
 {
 	GnomeCanvasItem *item = GNOME_CANVAS_ITEM (ecb);
-	GtkStyle *style;
 
-	style = gtk_widget_get_style (GTK_WIDGET (item->canvas));
-
-	if (gtk_widget_get_realized (GTK_WIDGET (item->canvas))) {
+	if (gtk_widget_get_realized (GTK_WIDGET (item->canvas)))
 		gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (ecb));
-	}
 }
 
 static void
