@@ -34,10 +34,6 @@
 #include "e-popup-action.h"
 #include "e-selectable.h"
 
-#define E_WEB_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_WEB_VIEW, EWebViewPrivate))
-
 typedef struct _EWebViewRequest EWebViewRequest;
 
 struct _EWebViewPrivate {
@@ -92,6 +88,7 @@ enum {
 	STATUS_MESSAGE,
 	STOP_LOADING,
 	UPDATE_ACTIONS,
+	PROCESS_MAILTO,
 	LAST_SIGNAL
 };
 
@@ -341,6 +338,7 @@ action_send_message_cb (GtkAction *action,
 {
 	const gchar *uri;
 	gpointer parent;
+	gboolean handled;
 
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (web_view));
 	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
@@ -348,7 +346,11 @@ action_send_message_cb (GtkAction *action,
 	uri = e_web_view_get_selected_uri (web_view);
 	g_return_if_fail (uri != NULL);
 
-	e_show_uri (parent, uri);
+	handled = FALSE;
+	g_signal_emit (web_view, signals[PROCESS_MAILTO], 0, uri, &handled);
+
+	if (!handled)
+		e_show_uri (parent, uri);
 }
 
 static void
@@ -674,7 +676,7 @@ web_view_dispose (GObject *object)
 {
 	EWebViewPrivate *priv;
 
-	priv = E_WEB_VIEW_GET_PRIVATE (object);
+	priv = E_WEB_VIEW (object)->priv;
 
 	if (priv->ui_manager != NULL) {
 		g_object_unref (priv->ui_manager);
@@ -715,7 +717,7 @@ web_view_finalize (GObject *object)
 {
 	EWebViewPrivate *priv;
 
-	priv = E_WEB_VIEW_GET_PRIVATE (object);
+	priv = E_WEB_VIEW (object)->priv;
 
 	/* All URI requests should be complete or cancelled by now. */
 	if (priv->requests != NULL)
@@ -1339,6 +1341,16 @@ e_web_view_class_init (EWebViewClass *class)
 		NULL, NULL,
 		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE, 0);
+
+	/* return TRUE when a signal handler processed the mailto URI */
+	signals[PROCESS_MAILTO] = g_signal_new (
+		"process-mailto",
+		G_TYPE_FROM_CLASS (class),
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (EWebViewClass, process_mailto),
+		NULL, NULL,
+		e_marshal_BOOLEAN__STRING,
+		G_TYPE_BOOLEAN, 1, G_TYPE_STRING);
 }
 
 static void
@@ -1362,7 +1374,8 @@ e_web_view_init (EWebView *web_view)
 	const gchar *id;
 	GError *error = NULL;
 
-	web_view->priv = E_WEB_VIEW_GET_PRIVATE (web_view);
+	web_view->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		web_view, E_TYPE_WEB_VIEW, EWebViewPrivate);
 
 	ui_manager = gtk_ui_manager_new ();
 	web_view->priv->ui_manager = ui_manager;
